Date: 07 11, 2001 12:20:32 PM

# Adding Rule Concepts

Rule concepts own a set of related samples, from which the rule generator will generalize, merge and generate rules.

To add a rule concept to a stub:

1. In the Gram Tab, select the stub where you want to add the rule concept.

2. Right click and select Add > Rule.

3. Give the rule concept a name in the dialog box.

4. Click OK to finish adding the rule concept.

Note: Rule concepts can be added to stub and folder concepts.

Tip: Add multiple rule concepts at the same time separating the names with commas. Use the yellow up and down arrows on the Tab Toolbar to move your rule concepts. Organize your rule concepts by using folders to the Gram Tab.

## See Also

Setting Concept Properties